@@ -12,6 +12,8 @@ override _build_WriteMakefile_args => sub {
 
     my $args = super();
 
+    $args->{PM}
+        = { 'lib/File/LibMagic.pm' => '$(INST_LIB)/File/LibMagic.pm' };
     $args->{LIBS}   = '-lmagic';
     $args->{INC}    = '-I. -Ic';
     $args->{XS}     = { 'lib/File/LibMagic.xs' => 'lib/File/LibMagic.c' };
